@@ -18,7 +18,9 @@ from silly_db.exceptions import (
 from silly_db.selections import (
     Selection,
     SelectionItem,
-    Model,
+)
+from silly_db.models import (
+    SillyModel,
 )
 
 
@@ -42,11 +44,16 @@ class DB:
         if file is None:
             raise SillyDbError(
                 "Missing parameter for DB: file=some_file_name.sqlite3")
-        self.file = os.path.join(base, file)
+        elif file.startswith("/") or file.startswith("~"):
+            self.file = os.path.expanduser(file)
+        else:
+            self.file = os.path.join(base, file)
         self.connection = sqlite3.connect(self.file)
         self.cursor = self.connection.cursor()
         if migrations_dir is None:
             self.migrations_dir = None
+        elif migrations_dir.startswith("/") or migrations_dir.startswith("~"):
+            self.migrations_dir = os.path.expanduser(migrations_dir)
         else:
             self.migrations_dir = os.path.join(base, migrations_dir)
         self.debug = debug
@@ -84,11 +91,6 @@ class DB:
                 )
         return uniques
 
-    def model(self, table):
-        """Takes a table name as parameter, returns the table as a Model"""
-        new_model = Model(self, table)
-        return new_model
-
     def execute(self, command):
         """'Begin transaction' and 'commit' are automatically added
         to the command, so don't use this key words."""
@@ -139,6 +141,11 @@ class DB:
         for file in files:
             self.migrate(os.path.abspath(os.path.join(apply_dir, file)))
 
+    def model(self, table):
+        """Takes a table name as parameter, returns the table as a Model"""
+        new_model = SillyModel(self, table)
+        return new_model
+
     def export(
         self,
         structure_file="00_structure.sql_bkp",
